==> qtjambi-remoteobjects-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiRemoteObjects/ClientIoDevice_shell.h <==
#ifndef CLIENTIODEVICE_SHELL_H
#define CLIENTIODEVICE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtRemoteObjects/5.15.2/QtRemoteObjects/private/qconnectionfactories_p.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QSet>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qstring.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtJambi/RegistryAPI>


class ClientIoDevice_shell : public ClientIoDevice, public QtJambiShellInterface
{
public:
    ClientIoDevice_shell(QObject* parent0 = nullptr);
    ~ClientIoDevice_shell() override;

    qint64 bytesAvailable() const override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void connectToServer() override;
    QIODevice* connection() const override;
    void customEvent(QEvent* event0) override;
    QString deviceType() const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void doClose() override;
    void doDisconnectFromServer() override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isOpen() const override;
    void timerEvent(QTimerEvent* event0) override;
    void write(const QByteArray& data0) override;
    void write(const QByteArray& data0, qint64 arg__2) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct ClientIoDevice_access : public ClientIoDevice
{
    void __qt_connectToServer(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_connection(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_deviceType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_doClose(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_doDisconnectFromServer(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // CLIENTIODEVICE_SHELL_H

==> qtjambi-remoteobjects-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiRemoteObjects/ClientIoDevice_shell.h <==
#ifndef CLIENTIODEVICE_SHELL_H
#define CLIENTIODEVICE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtRemoteObjects/private/qconnectionfactories_p.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QSet>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qdatastream.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qstring.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtJambi/RegistryAPI>


class ClientIoDevice_shell : public ClientIoDevice, public QtJambiShellInterface
{
public:
    ClientIoDevice_shell(QObject* parent0 = nullptr);
    ~ClientIoDevice_shell() override;

    qint64 bytesAvailable() const override;
    void childEvent(QChildEvent* event0) override;
    void close() override;
    void connectNotify(const QMetaMethod& signal0) override;
    void connectToServer() override;
    QIODevice* connection() const override;
    void customEvent(QEvent* event0) override;
    QString deviceType() const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void doClose() override;
    void doDisconnectFromServer() override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool isOpen() const override;
    void timerEvent(QTimerEvent* event0) override;
    void write(const QByteArray& data0) override;
    void write(const QByteArray& data0, qint64 arg__2) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct ClientIoDevice_access : public ClientIoDevice
{
    void __qt_connectToServer(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_connection_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_deviceType_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_doClose(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_doDisconnectFromServer(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // CLIENTIODEVICE_SHELL_H
